#!/bin/sh -e
# SPDX-License-Identifier: GPL-3.0-or-later
# Copyright 2023 Oliver Smith
# Run checkpatch against relevant files in the repository.
SCRIPT_DIR="$(dirname "$(realpath "$0")")"

# Download checkpatch from linux.git
cd "$SCRIPT_DIR"
for f in checkpatch.pl spelling.txt; do
	if ! [ -e "$SCRIPT_DIR/$f" ]; then
		url="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/plain/scripts/$f"
		echo "Download: $url"
		wget -q "$url"
		chmod +x "$f"
	fi
done

cd ..

# NOTE: giving all files directly as arguments to checkpatch.pl was buggy, so
# call it once per file for now. See .checkpatch.conf for additional options.

err=0
for i in src/*.c src/*.h .ci/*.sh; do
	./.ci/checkpatch.pl \
		--color=always \
		--mailback \
		--show-types \
		--showfile \
		--no-summary \
		--terse \
		"$i" || err=1
done

if [ "$err" = 1 ]; then
	echo
	echo "Please fix the errors/warnings above."
	echo
	echo "Run the script locally with:"
	echo "  .ci/lint.sh"
	echo
fi

exit $err
